# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pipeline/pipeline/v1beta/integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pipeline.pipeline.v1beta import common_pb2 as pipeline_dot_pipeline_dot_v1beta_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*pipeline/pipeline/v1beta/integration.proto\x12\x18pipeline.pipeline.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%pipeline/pipeline/v1beta/common.proto\"\x87\x06\n\nConnection\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x02id\x12&\n\x0cnamespace_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0bnamespaceId\x12-\n\x0eintegration_id\x18\x04 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05R\rintegrationId\x12\x30\n\x11integration_title\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x10integrationTitle\x12H\n\x06method\x18\x06 \x01(\x0e\x32+.pipeline.pipeline.v1beta.Connection.MethodB\x03\xe0\x41\x02R\x06method\x12\x32\n\x05setup\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\x05setup\x12\x1b\n\x06scopes\x18\x0b \x03(\tB\x03\xe0\x41\x01R\x06scopes\x12$\n\x08identity\x18\r \x01(\tB\x03\xe0\x41\x01H\x00R\x08identity\x88\x01\x01\x12T\n\x15o_auth_access_details\x18\x0c \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x01H\x01R\x12oAuthAccessDetails\x88\x01\x01\x12\x37\n\x04view\x18\x08 \x01(\x0e\x32\x1e.pipeline.pipeline.v1beta.ViewB\x03\xe0\x41\x03R\x04view\x12@\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\"I\n\x06Method\x12\x16\n\x12METHOD_UNSPECIFIED\x10\x00\x12\x15\n\x11METHOD_DICTIONARY\x10\x01\x12\x10\n\x0cMETHOD_OAUTH\x10\x02\x42\x0b\n\t_identityB\x18\n\x16_o_auth_access_details\"\xe3\x01\n\x1fListNamespaceConnectionsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12%\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xc0\x01\n ListNamespaceConnectionsResponse\x12K\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\x0b\x63onnections\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xb8\x01\n\x1dGetNamespaceConnectionRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12(\n\rconnection_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\x12<\n\x04view\x18\x03 \x01(\x0e\x32\x1e.pipeline.pipeline.v1beta.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"k\n\x1eGetNamespaceConnectionResponse\x12I\n\nconnection\x18\x01 \x01(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\nconnection\"\x95\x01\n CreateNamespaceConnectionRequest\x12&\n\x0cnamespace_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12I\n\nconnection\x18\x01 \x01(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x02R\nconnection\"n\n!CreateNamespaceConnectionResponse\x12I\n\nconnection\x18\x01 \x01(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\nconnection\"\x81\x02\n UpdateNamespaceConnectionRequest\x12(\n\rconnection_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\x12&\n\x0cnamespace_id\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12I\n\nconnection\x18\x02 \x01(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x02R\nconnection\x12@\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"n\n!UpdateNamespaceConnectionResponse\x12I\n\nconnection\x18\x01 \x01(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\nconnection\"t\n DeleteNamespaceConnectionRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12(\n\rconnection_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\"#\n!DeleteNamespaceConnectionResponse\"r\n\x1eTestNamespaceConnectionRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12(\n\rconnection_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\"!\n\x1fTestNamespaceConnectionResponse\"\xa7\x05\n\x0bIntegration\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x02id\x12\x19\n\x05title\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x05title\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x65scription\x12\x1b\n\x06vendor\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x06vendor\x12\x17\n\x04icon\x18\x06 \x01(\tB\x03\xe0\x41\x03R\x04icon\x12Q\n\thelp_link\x18\x07 \x01(\x0b\x32*.pipeline.pipeline.v1beta.Integration.LinkB\x03\xe0\x41\x03H\x00R\x08helpLink\x88\x01\x01\x12?\n\x0csetup_schema\x18\n \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0bsetupSchema\x12_\n\ro_auth_config\x18\x0b \x01(\x0b\x32\x31.pipeline.pipeline.v1beta.Integration.OAuthConfigB\x03\xe0\x41\x03H\x01R\x0boAuthConfig\x88\x01\x01\x12\x37\n\x04view\x18\t \x01(\x0e\x32\x1e.pipeline.pipeline.v1beta.ViewB\x03\xe0\x41\x03R\x04view\x1a\x36\n\x04Link\x12\x17\n\x04text\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04text\x12\x15\n\x03url\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x03url\x1an\n\x0bOAuthConfig\x12\x1e\n\x08\x61uth_url\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07\x61uthUrl\x12\"\n\naccess_url\x18\x02 \x01(\tB\x03\xe0\x41\x03R\taccessUrl\x12\x1b\n\x06scopes\x18\x0b \x03(\tB\x03\xe0\x41\x03R\x06scopesB\x0c\n\n_help_linkB\x10\n\x0e_o_auth_config\"\x92\x02\n$ListPipelineIDsByConnectionIDRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12(\n\rconnection_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\x12%\n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12 \n\x06\x66ilter\x18\x05 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xa0\x01\n%ListPipelineIDsByConnectionIDResponse\x12&\n\x0cpipeline_ids\x18\x01 \x03(\tB\x03\xe0\x41\x03R\x0bpipelineIds\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xb3\x01\n\x17ListIntegrationsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12 \n\x06\x66ilter\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xbb\x01\n\x18ListIntegrationsResponse\x12N\n\x0cintegrations\x18\x01 \x03(\x0b\x32%.pipeline.pipeline.v1beta.IntegrationB\x03\xe0\x41\x03R\x0cintegrations\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\x8a\x01\n\x15GetIntegrationRequest\x12*\n\x0eintegration_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\rintegrationId\x12<\n\x04view\x18\x02 \x01(\x0e\x32\x1e.pipeline.pipeline.v1beta.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"f\n\x16GetIntegrationResponse\x12L\n\x0bintegration\x18\x01 \x01(\x0b\x32%.pipeline.pipeline.v1beta.IntegrationB\x03\xe0\x41\x03R\x0bintegration\"|\n\x1cLookUpConnectionAdminRequest\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x03uid\x12<\n\x04view\x18\x02 \x01(\x0e\x32\x1e.pipeline.pipeline.v1beta.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"j\n\x1dLookUpConnectionAdminResponse\x12I\n\nconnection\x18\x01 \x01(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\nconnectionB\xfd\x01\n\x1c\x63om.pipeline.pipeline.v1betaB\x10IntegrationProtoP\x01ZIgithub.com/instill-ai/protogen-go/pipeline/pipeline/v1beta;pipelinev1beta\xa2\x02\x03PPX\xaa\x02\x18Pipeline.Pipeline.V1beta\xca\x02\x18Pipeline\\Pipeline\\V1beta\xe2\x02$Pipeline\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x1aPipeline::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pipeline.pipeline.v1beta.integration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.pipeline.pipeline.v1betaB\020IntegrationProtoP\001ZIgithub.com/instill-ai/protogen-go/pipeline/pipeline/v1beta;pipelinev1beta\242\002\003PPX\252\002\030Pipeline.Pipeline.V1beta\312\002\030Pipeline\\Pipeline\\V1beta\342\002$Pipeline\\Pipeline\\V1beta\\GPBMetadata\352\002\032Pipeline::Pipeline::V1beta'
  _CONNECTION.fields_by_name['uid']._options = None
  _CONNECTION.fields_by_name['uid']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['id']._options = None
  _CONNECTION.fields_by_name['id']._serialized_options = b'\340A\002'
  _CONNECTION.fields_by_name['namespace_id']._options = None
  _CONNECTION.fields_by_name['namespace_id']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['integration_id']._options = None
  _CONNECTION.fields_by_name['integration_id']._serialized_options = b'\340A\002\340A\005'
  _CONNECTION.fields_by_name['integration_title']._options = None
  _CONNECTION.fields_by_name['integration_title']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['method']._options = None
  _CONNECTION.fields_by_name['method']._serialized_options = b'\340A\002'
  _CONNECTION.fields_by_name['setup']._options = None
  _CONNECTION.fields_by_name['setup']._serialized_options = b'\340A\002'
  _CONNECTION.fields_by_name['scopes']._options = None
  _CONNECTION.fields_by_name['scopes']._serialized_options = b'\340A\001'
  _CONNECTION.fields_by_name['identity']._options = None
  _CONNECTION.fields_by_name['identity']._serialized_options = b'\340A\001'
  _CONNECTION.fields_by_name['o_auth_access_details']._options = None
  _CONNECTION.fields_by_name['o_auth_access_details']._serialized_options = b'\340A\001'
  _CONNECTION.fields_by_name['view']._options = None
  _CONNECTION.fields_by_name['view']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['create_time']._options = None
  _CONNECTION.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['update_time']._options = None
  _CONNECTION.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['filter']._options = None
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['connections']._options = None
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['connections']._serialized_options = b'\340A\003'
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['view']._options = None
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETNAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._options = None
  _GETNAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._serialized_options = b'\340A\003'
  _CREATENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _CREATENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATENAMESPACECONNECTIONREQUEST.fields_by_name['connection']._options = None
  _CREATENAMESPACECONNECTIONREQUEST.fields_by_name['connection']._serialized_options = b'\340A\002'
  _CREATENAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._options = None
  _CREATENAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._serialized_options = b'\340A\003'
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['connection']._options = None
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['connection']._serialized_options = b'\340A\002'
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['update_mask']._options = None
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATENAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._options = None
  _UPDATENAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._serialized_options = b'\340A\003'
  _DELETENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _DELETENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETENAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _DELETENAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _TESTNAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _TESTNAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TESTNAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _TESTNAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _INTEGRATION_LINK.fields_by_name['text']._options = None
  _INTEGRATION_LINK.fields_by_name['text']._serialized_options = b'\340A\003'
  _INTEGRATION_LINK.fields_by_name['url']._options = None
  _INTEGRATION_LINK.fields_by_name['url']._serialized_options = b'\340A\003'
  _INTEGRATION_OAUTHCONFIG.fields_by_name['auth_url']._options = None
  _INTEGRATION_OAUTHCONFIG.fields_by_name['auth_url']._serialized_options = b'\340A\003'
  _INTEGRATION_OAUTHCONFIG.fields_by_name['access_url']._options = None
  _INTEGRATION_OAUTHCONFIG.fields_by_name['access_url']._serialized_options = b'\340A\003'
  _INTEGRATION_OAUTHCONFIG.fields_by_name['scopes']._options = None
  _INTEGRATION_OAUTHCONFIG.fields_by_name['scopes']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['uid']._options = None
  _INTEGRATION.fields_by_name['uid']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['id']._options = None
  _INTEGRATION.fields_by_name['id']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['title']._options = None
  _INTEGRATION.fields_by_name['title']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['description']._options = None
  _INTEGRATION.fields_by_name['description']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['vendor']._options = None
  _INTEGRATION.fields_by_name['vendor']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['icon']._options = None
  _INTEGRATION.fields_by_name['icon']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['help_link']._options = None
  _INTEGRATION.fields_by_name['help_link']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['setup_schema']._options = None
  _INTEGRATION.fields_by_name['setup_schema']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['o_auth_config']._options = None
  _INTEGRATION.fields_by_name['o_auth_config']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['view']._options = None
  _INTEGRATION.fields_by_name['view']._serialized_options = b'\340A\003'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['namespace_id']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['connection_id']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['pipeline_ids']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['pipeline_ids']._serialized_options = b'\340A\003'
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['total_size']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTINTEGRATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTINTEGRATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTINTEGRATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTINTEGRATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTINTEGRATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTINTEGRATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTINTEGRATIONSRESPONSE.fields_by_name['integrations']._options = None
  _LISTINTEGRATIONSRESPONSE.fields_by_name['integrations']._serialized_options = b'\340A\003'
  _LISTINTEGRATIONSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTINTEGRATIONSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTINTEGRATIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTINTEGRATIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _GETINTEGRATIONREQUEST.fields_by_name['integration_id']._options = None
  _GETINTEGRATIONREQUEST.fields_by_name['integration_id']._serialized_options = b'\340A\002'
  _GETINTEGRATIONREQUEST.fields_by_name['view']._options = None
  _GETINTEGRATIONREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETINTEGRATIONRESPONSE.fields_by_name['integration']._options = None
  _GETINTEGRATIONRESPONSE.fields_by_name['integration']._serialized_options = b'\340A\003'
  _LOOKUPCONNECTIONADMINREQUEST.fields_by_name['uid']._options = None
  _LOOKUPCONNECTIONADMINREQUEST.fields_by_name['uid']._serialized_options = b'\340A\002'
  _LOOKUPCONNECTIONADMINREQUEST.fields_by_name['view']._options = None
  _LOOKUPCONNECTIONADMINREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LOOKUPCONNECTIONADMINRESPONSE.fields_by_name['connection']._options = None
  _LOOKUPCONNECTIONADMINRESPONSE.fields_by_name['connection']._serialized_options = b'\340A\003'
  _globals['_CONNECTION']._serialized_start=242
  _globals['_CONNECTION']._serialized_end=1017
  _globals['_CONNECTION_METHOD']._serialized_start=905
  _globals['_CONNECTION_METHOD']._serialized_end=978
  _globals['_LISTNAMESPACECONNECTIONSREQUEST']._serialized_start=1020
  _globals['_LISTNAMESPACECONNECTIONSREQUEST']._serialized_end=1247
  _globals['_LISTNAMESPACECONNECTIONSRESPONSE']._serialized_start=1250
  _globals['_LISTNAMESPACECONNECTIONSRESPONSE']._serialized_end=1442
  _globals['_GETNAMESPACECONNECTIONREQUEST']._serialized_start=1445
  _globals['_GETNAMESPACECONNECTIONREQUEST']._serialized_end=1629
  _globals['_GETNAMESPACECONNECTIONRESPONSE']._serialized_start=1631
  _globals['_GETNAMESPACECONNECTIONRESPONSE']._serialized_end=1738
  _globals['_CREATENAMESPACECONNECTIONREQUEST']._serialized_start=1741
  _globals['_CREATENAMESPACECONNECTIONREQUEST']._serialized_end=1890
  _globals['_CREATENAMESPACECONNECTIONRESPONSE']._serialized_start=1892
  _globals['_CREATENAMESPACECONNECTIONRESPONSE']._serialized_end=2002
  _globals['_UPDATENAMESPACECONNECTIONREQUEST']._serialized_start=2005
  _globals['_UPDATENAMESPACECONNECTIONREQUEST']._serialized_end=2262
  _globals['_UPDATENAMESPACECONNECTIONRESPONSE']._serialized_start=2264
  _globals['_UPDATENAMESPACECONNECTIONRESPONSE']._serialized_end=2374
  _globals['_DELETENAMESPACECONNECTIONREQUEST']._serialized_start=2376
  _globals['_DELETENAMESPACECONNECTIONREQUEST']._serialized_end=2492
  _globals['_DELETENAMESPACECONNECTIONRESPONSE']._serialized_start=2494
  _globals['_DELETENAMESPACECONNECTIONRESPONSE']._serialized_end=2529
  _globals['_TESTNAMESPACECONNECTIONREQUEST']._serialized_start=2531
  _globals['_TESTNAMESPACECONNECTIONREQUEST']._serialized_end=2645
  _globals['_TESTNAMESPACECONNECTIONRESPONSE']._serialized_start=2647
  _globals['_TESTNAMESPACECONNECTIONRESPONSE']._serialized_end=2680
  _globals['_INTEGRATION']._serialized_start=2683
  _globals['_INTEGRATION']._serialized_end=3362
  _globals['_INTEGRATION_LINK']._serialized_start=3164
  _globals['_INTEGRATION_LINK']._serialized_end=3218
  _globals['_INTEGRATION_OAUTHCONFIG']._serialized_start=3220
  _globals['_INTEGRATION_OAUTHCONFIG']._serialized_end=3330
  _globals['_LISTPIPELINEIDSBYCONNECTIONIDREQUEST']._serialized_start=3365
  _globals['_LISTPIPELINEIDSBYCONNECTIONIDREQUEST']._serialized_end=3639
  _globals['_LISTPIPELINEIDSBYCONNECTIONIDRESPONSE']._serialized_start=3642
  _globals['_LISTPIPELINEIDSBYCONNECTIONIDRESPONSE']._serialized_end=3802
  _globals['_LISTINTEGRATIONSREQUEST']._serialized_start=3805
  _globals['_LISTINTEGRATIONSREQUEST']._serialized_end=3984
  _globals['_LISTINTEGRATIONSRESPONSE']._serialized_start=3987
  _globals['_LISTINTEGRATIONSRESPONSE']._serialized_end=4174
  _globals['_GETINTEGRATIONREQUEST']._serialized_start=4177
  _globals['_GETINTEGRATIONREQUEST']._serialized_end=4315
  _globals['_GETINTEGRATIONRESPONSE']._serialized_start=4317
  _globals['_GETINTEGRATIONRESPONSE']._serialized_end=4419
  _globals['_LOOKUPCONNECTIONADMINREQUEST']._serialized_start=4421
  _globals['_LOOKUPCONNECTIONADMINREQUEST']._serialized_end=4545
  _globals['_LOOKUPCONNECTIONADMINRESPONSE']._serialized_start=4547
  _globals['_LOOKUPCONNECTIONADMINRESPONSE']._serialized_end=4653
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import grpc
import grpc.aio
import model.ray.v1alpha.user_defined_pb2
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class UserDefinedServiceStub:
    """User defined service for internal process"""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    __call__: grpc.UnaryUnaryMultiCallable[
        model.ray.v1alpha.user_defined_pb2.CallRequest,
        model.ray.v1alpha.user_defined_pb2.CallResponse,
    ]
    """Trigger method is the default trigger entry for ray deployment
    Ray doesn't comply with the naming convention of protobuf, so we need to
    buf:lint:ignore RPC_PASCAL_CASE
    """

class UserDefinedServiceAsyncStub:
    """User defined service for internal process"""

    __call__: grpc.aio.UnaryUnaryMultiCallable[
        model.ray.v1alpha.user_defined_pb2.CallRequest,
        model.ray.v1alpha.user_defined_pb2.CallResponse,
    ]
    """Trigger method is the default trigger entry for ray deployment
    Ray doesn't comply with the naming convention of protobuf, so we need to
    buf:lint:ignore RPC_PASCAL_CASE
    """

class UserDefinedServiceServicer(metaclass=abc.ABCMeta):
    """User defined service for internal process"""

    @abc.abstractmethod
    def __call__(
        self,
        request: model.ray.v1alpha.user_defined_pb2.CallRequest,
        context: _ServicerContext,
    ) -> typing.Union[model.ray.v1alpha.user_defined_pb2.CallResponse, collections.abc.Awaitable[model.ray.v1alpha.user_defined_pb2.CallResponse]]:
        """Trigger method is the default trigger entry for ray deployment
        Ray doesn't comply with the naming convention of protobuf, so we need to
        buf:lint:ignore RPC_PASCAL_CASE
        """

def add_UserDefinedServiceServicer_to_server(servicer: UserDefinedServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: openapi/v2/conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15openapi/v2/conf.proto\x12\nopenapi.v2\x1a.protoc-gen-openapiv2/options/annotations.protoB\xaf\t\n\x0e\x63om.openapi.v2B\tConfProtoP\x01Z6github.com/instill-ai/protogen-go/openapi/v2;openapiv2\xa2\x02\x03OXX\xaa\x02\nOpenapi.V2\xca\x02\nOpenapi\\V2\xe2\x02\x16Openapi\\V2\\GPBMetadata\xea\x02\x0bOpenapi::V2\x92\x41\x8f\x08\x12\xee\x01\n\x13\xf0\x9f\x94\xae Instill AI API\x12/Interact with Instill AI through its public API\"?\n\nInstill AI\x12\x1dhttps://github.com/instill-ai\x1a\x12hello@instill.tech*W\n\x1a\x45lastic License 2.0 (ELv2)\x12\x39https://github.com/instill-ai/protobufs/blob/main/LICENSE2\x0cv0.50.4-beta\x1a\x12\x61pi.instill-ai.com*\x02\x02\x01\x32\x10\x61pplication/json:\x10\x61pplication/jsonR<\n\x03\x34\x30\x31\x12\x35\n3Returned when the client credentials are not valid.Z\x8b\x01\n\x88\x01\n\x06\x42\x65\x61rer\x12~\x08\x02\x12\x43\x45nter the token with the `Bearer ` prefix, e.g. `Bearer abcde12345`\x1a\rAuthorization \x02J$\n\tx-default\x12\x17\x1a\x15\x42\x65\x61rer instill_sk_***b\x0c\n\n\n\x06\x42\x65\x61rer\x12\x00j]\n\x0e\xf0\x9f\xaa\x86 Namespace\x12KNamespaces (e.g. User, Organization) that structure the resource hierarchy.j8\n\r\xf0\x9f\x92\xa7 Pipeline\x12\'Pipeline orchestration in Instill Core.j4\n\x0c\xe2\x9a\x97\xef\xb8\x8f Model\x12$AI Model resources for MLOps/LLMOps.jQ\n\r\xf0\x9f\x92\xbe Artifact\x12@Data orchestration for unified unstructured data representation.j%\n\n\xf0\x9f\x8d\x8e Agent\x12\x17Ready-to-use AI agents.j$\n\x05Table\x12\x1bTable resources for agents.j\'\n\x0c\xf0\x9f\x93\x8a Metrics\x12\x17Resource usage metrics.j4\n\x11\xf0\x9f\xa4\x9d Subscription\x12\x1fPricing plans on Instill Cloud.r8\n\x15More about Instill AI\x12\x1fhttps://www.instill-ai.dev/docsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'openapi.v2.conf_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.openapi.v2B\tConfProtoP\001Z6github.com/instill-ai/protogen-go/openapi/v2;openapiv2\242\002\003OXX\252\002\nOpenapi.V2\312\002\nOpenapi\\V2\342\002\026Openapi\\V2\\GPBMetadata\352\002\013Openapi::V2\222A\217\010\022\356\001\n\023\360\237\224\256 Instill AI API\022/Interact with Instill AI through its public API\"?\n\nInstill AI\022\035https://github.com/instill-ai\032\022hello@instill.tech*W\n\032Elastic License 2.0 (ELv2)\0229https://github.com/instill-ai/protobufs/blob/main/LICENSE2\014v0.50.4-beta\032\022api.instill-ai.com*\002\002\0012\020application/json:\020application/jsonR<\n\003401\0225\n3Returned when the client credentials are not valid.Z\213\001\n\210\001\n\006Bearer\022~\010\002\022CEnter the token with the `Bearer ` prefix, e.g. `Bearer abcde12345`\032\rAuthorization \002J$\n\tx-default\022\027\032\025Bearer instill_sk_***b\014\n\n\n\006Bearer\022\000j]\n\016\360\237\252\206 Namespace\022KNamespaces (e.g. User, Organization) that structure the resource hierarchy.j8\n\r\360\237\222\247 Pipeline\022\'Pipeline orchestration in Instill Core.j4\n\014\342\232\227\357\270\217 Model\022$AI Model resources for MLOps/LLMOps.jQ\n\r\360\237\222\276 Artifact\022@Data orchestration for unified unstructured data representation.j%\n\n\360\237\215\216 Agent\022\027Ready-to-use AI agents.j$\n\005Table\022\033Table resources for agents.j\'\n\014\360\237\223\212 Metrics\022\027Resource usage metrics.j4\n\021\360\237\244\235 Subscription\022\037Pricing plans on Instill Cloud.r8\n\025More about Instill AI\022\037https://www.instill-ai.dev/docs'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/chunk.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%artifact/artifact/v1alpha/chunk.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf0\x02\n\x05\x43hunk\x12 \n\tchunk_uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x08\x63hunkUid\x12%\n\x0bretrievable\x18\x02 \x01(\x08\x42\x03\xe0\x41\x03R\x0bretrievable\x12 \n\tstart_pos\x18\x04 \x01(\rB\x03\xe0\x41\x03R\x08startPos\x12\x1c\n\x07\x65nd_pos\x18\x05 \x01(\rB\x03\xe0\x41\x03R\x06\x65ndPos\x12\x1b\n\x06tokens\x18\x06 \x01(\rB\x03\xe0\x41\x03R\x06tokens\x12@\n\x0b\x63reate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12/\n\x11original_file_uid\x18\x08 \x01(\tB\x03\xe0\x41\x03R\x0foriginalFileUid\x12N\n\x0c\x63ontent_type\x18\t \x01(\x0e\x32&.artifact.artifact.v1alpha.ContentTypeB\x03\xe0\x41\x03R\x0b\x63ontentType\"\x7f\n\x11ListChunksRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\"\n\ncatalog_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tcatalogId\x12\x1e\n\x08\x66ile_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07\x66ileUid\"S\n\x12ListChunksResponse\x12=\n\x06\x63hunks\x18\x01 \x03(\x0b\x32 .artifact.artifact.v1alpha.ChunkB\x03\xe0\x41\x03R\x06\x63hunks\"a\n\x13SearchChunksRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\"\n\nchunk_uids\x18\x02 \x03(\tB\x03\xe0\x41\x02R\tchunkUids\"U\n\x14SearchChunksResponse\x12=\n\x06\x63hunks\x18\x01 \x03(\x0b\x32 .artifact.artifact.v1alpha.ChunkB\x03\xe0\x41\x03R\x06\x63hunks\"\x93\x02\n\nSourceFile\x12/\n\x11original_file_uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0foriginalFileUid\x12\x1d\n\x07\x63ontent\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x07\x63ontent\x12@\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12\x31\n\x12original_file_name\x18\x07 \x01(\tB\x03\xe0\x41\x03R\x10originalFileName\"\x82\x01\n\x14GetSourceFileRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\"\n\ncatalog_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tcatalogId\x12\x1e\n\x08\x66ile_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07\x66ileUid\"d\n\x15GetSourceFileResponse\x12K\n\x0bsource_file\x18\x01 \x01(\x0b\x32%.artifact.artifact.v1alpha.SourceFileB\x03\xe0\x41\x03R\nsourceFile\"\x83\x01\n\x15GetFileSummaryRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\"\n\ncatalog_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tcatalogId\x12\x1e\n\x08\x66ile_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07\x66ileUid\"7\n\x16GetFileSummaryResponse\x12\x1d\n\x07summary\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07summary\"d\n\x18SearchSourceFilesRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\tfile_uids\x18\x02 \x03(\tB\x03\xe0\x41\x02R\x08\x66ileUids\"j\n\x19SearchSourceFilesResponse\x12M\n\x0csource_files\x18\x01 \x03(\x0b\x32%.artifact.artifact.v1alpha.SourceFileB\x03\xe0\x41\x03R\x0bsourceFiles\"]\n\x12UpdateChunkRequest\x12 \n\tchunk_uid\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x08\x63hunkUid\x12%\n\x0bretrievable\x18\x02 \x01(\x08\x42\x03\xe0\x41\x02R\x0bretrievable\"R\n\x13UpdateChunkResponse\x12;\n\x05\x63hunk\x18\x01 \x01(\x0b\x32 .artifact.artifact.v1alpha.ChunkB\x03\xe0\x41\x03R\x05\x63hunk\"\xf4\x02\n\x1dSimilarityChunksSearchRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\"\n\ncatalog_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tcatalogId\x12$\n\x0btext_prompt\x18\x03 \x01(\tB\x03\xe0\x41\x02R\ntextPrompt\x12\x18\n\x05top_k\x18\x04 \x01(\rB\x03\xe0\x41\x01R\x04topK\x12 \n\tfile_name\x18\x05 \x01(\tB\x03\xe0\x41\x01R\x08\x66ileName\x12N\n\x0c\x63ontent_type\x18\x06 \x01(\x0e\x32&.artifact.artifact.v1alpha.ContentTypeB\x03\xe0\x41\x01R\x0b\x63ontentType\x12U\n\x0f\x66ile_media_type\x18\x07 \x01(\x0e\x32(.artifact.artifact.v1alpha.FileMediaTypeB\x03\xe0\x41\x01R\rfileMediaType\"x\n\x1eSimilarityChunksSearchResponse\x12V\n\x0esimilar_chunks\x18\x01 \x03(\x0b\x32*.artifact.artifact.v1alpha.SimilarityChunkB\x03\xe0\x41\x03R\rsimilarChunks\"\xff\x01\n\x0fSimilarityChunk\x12 \n\tchunk_uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x08\x63hunkUid\x12.\n\x10similarity_score\x18\x02 \x01(\x02\x42\x03\xe0\x41\x03R\x0fsimilarityScore\x12&\n\x0ctext_content\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0btextContent\x12$\n\x0bsource_file\x18\x04 \x01(\tB\x03\xe0\x41\x03R\nsourceFile\x12L\n\x0e\x63hunk_metadata\x18\x05 \x01(\x0b\x32 .artifact.artifact.v1alpha.ChunkB\x03\xe0\x41\x03R\rchunkMetadata*\x9f\x01\n\rFileMediaType\x12\x1f\n\x1b\x46ILE_MEDIA_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x46ILE_MEDIA_TYPE_DOCUMENT\x10\x01\x12\x19\n\x15\x46ILE_MEDIA_TYPE_IMAGE\x10\x02\x12\x19\n\x15\x46ILE_MEDIA_TYPE_AUDIO\x10\x03\x12\x19\n\x15\x46ILE_MEDIA_TYPE_VIDEO\x10\x04*y\n\x0b\x43ontentType\x12\x1c\n\x18\x43ONTENT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x43ONTENT_TYPE_CHUNK\x10\x01\x12\x18\n\x14\x43ONTENT_TYPE_SUMMARY\x10\x02\x12\x1a\n\x16\x43ONTENT_TYPE_AUGMENTED\x10\x03\x42\xfe\x01\n\x1d\x63om.artifact.artifact.v1alphaB\nChunkProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.chunk_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\nChunkProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _CHUNK.fields_by_name['chunk_uid']._options = None
  _CHUNK.fields_by_name['chunk_uid']._serialized_options = b'\340A\003'
  _CHUNK.fields_by_name['retrievable']._options = None
  _CHUNK.fields_by_name['retrievable']._serialized_options = b'\340A\003'
  _CHUNK.fields_by_name['start_pos']._options = None
  _CHUNK.fields_by_name['start_pos']._serialized_options = b'\340A\003'
  _CHUNK.fields_by_name['end_pos']._options = None
  _CHUNK.fields_by_name['end_pos']._serialized_options = b'\340A\003'
  _CHUNK.fields_by_name['tokens']._options = None
  _CHUNK.fields_by_name['tokens']._serialized_options = b'\340A\003'
  _CHUNK.fields_by_name['create_time']._options = None
  _CHUNK.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHUNK.fields_by_name['original_file_uid']._options = None
  _CHUNK.fields_by_name['original_file_uid']._serialized_options = b'\340A\003'
  _CHUNK.fields_by_name['content_type']._options = None
  _CHUNK.fields_by_name['content_type']._serialized_options = b'\340A\003'
  _LISTCHUNKSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTCHUNKSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTCHUNKSREQUEST.fields_by_name['catalog_id']._options = None
  _LISTCHUNKSREQUEST.fields_by_name['catalog_id']._serialized_options = b'\340A\002'
  _LISTCHUNKSREQUEST.fields_by_name['file_uid']._options = None
  _LISTCHUNKSREQUEST.fields_by_name['file_uid']._serialized_options = b'\340A\002'
  _LISTCHUNKSRESPONSE.fields_by_name['chunks']._options = None
  _LISTCHUNKSRESPONSE.fields_by_name['chunks']._serialized_options = b'\340A\003'
  _SEARCHCHUNKSREQUEST.fields_by_name['namespace_id']._options = None
  _SEARCHCHUNKSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _SEARCHCHUNKSREQUEST.fields_by_name['chunk_uids']._options = None
  _SEARCHCHUNKSREQUEST.fields_by_name['chunk_uids']._serialized_options = b'\340A\002'
  _SEARCHCHUNKSRESPONSE.fields_by_name['chunks']._options = None
  _SEARCHCHUNKSRESPONSE.fields_by_name['chunks']._serialized_options = b'\340A\003'
  _SOURCEFILE.fields_by_name['original_file_uid']._options = None
  _SOURCEFILE.fields_by_name['original_file_uid']._serialized_options = b'\340A\003'
  _SOURCEFILE.fields_by_name['content']._options = None
  _SOURCEFILE.fields_by_name['content']._serialized_options = b'\340A\003'
  _SOURCEFILE.fields_by_name['create_time']._options = None
  _SOURCEFILE.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _SOURCEFILE.fields_by_name['update_time']._options = None
  _SOURCEFILE.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _SOURCEFILE.fields_by_name['original_file_name']._options = None
  _SOURCEFILE.fields_by_name['original_file_name']._serialized_options = b'\340A\003'
  _GETSOURCEFILEREQUEST.fields_by_name['namespace_id']._options = None
  _GETSOURCEFILEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETSOURCEFILEREQUEST.fields_by_name['catalog_id']._options = None
  _GETSOURCEFILEREQUEST.fields_by_name['catalog_id']._serialized_options = b'\340A\002'
  _GETSOURCEFILEREQUEST.fields_by_name['file_uid']._options = None
  _GETSOURCEFILEREQUEST.fields_by_name['file_uid']._serialized_options = b'\340A\002'
  _GETSOURCEFILERESPONSE.fields_by_name['source_file']._options = None
  _GETSOURCEFILERESPONSE.fields_by_name['source_file']._serialized_options = b'\340A\003'
  _GETFILESUMMARYREQUEST.fields_by_name['namespace_id']._options = None
  _GETFILESUMMARYREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETFILESUMMARYREQUEST.fields_by_name['catalog_id']._options = None
  _GETFILESUMMARYREQUEST.fields_by_name['catalog_id']._serialized_options = b'\340A\002'
  _GETFILESUMMARYREQUEST.fields_by_name['file_uid']._options = None
  _GETFILESUMMARYREQUEST.fields_by_name['file_uid']._serialized_options = b'\340A\002'
  _GETFILESUMMARYRESPONSE.fields_by_name['summary']._options = None
  _GETFILESUMMARYRESPONSE.fields_by_name['summary']._serialized_options = b'\340A\003'
  _SEARCHSOURCEFILESREQUEST.fields_by_name['namespace_id']._options = None
  _SEARCHSOURCEFILESREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _SEARCHSOURCEFILESREQUEST.fields_by_name['file_uids']._options = None
  _SEARCHSOURCEFILESREQUEST.fields_by_name['file_uids']._serialized_options = b'\340A\002'
  _SEARCHSOURCEFILESRESPONSE.fields_by_name['source_files']._options = None
  _SEARCHSOURCEFILESRESPONSE.fields_by_name['source_files']._serialized_options = b'\340A\003'
  _UPDATECHUNKREQUEST.fields_by_name['chunk_uid']._options = None
  _UPDATECHUNKREQUEST.fields_by_name['chunk_uid']._serialized_options = b'\340A\002'
  _UPDATECHUNKREQUEST.fields_by_name['retrievable']._options = None
  _UPDATECHUNKREQUEST.fields_by_name['retrievable']._serialized_options = b'\340A\002'
  _UPDATECHUNKRESPONSE.fields_by_name['chunk']._options = None
  _UPDATECHUNKRESPONSE.fields_by_name['chunk']._serialized_options = b'\340A\003'
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['namespace_id']._options = None
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['catalog_id']._options = None
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['catalog_id']._serialized_options = b'\340A\002'
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['text_prompt']._options = None
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['text_prompt']._serialized_options = b'\340A\002'
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['top_k']._options = None
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['top_k']._serialized_options = b'\340A\001'
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['file_name']._options = None
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['file_name']._serialized_options = b'\340A\001'
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['content_type']._options = None
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['content_type']._serialized_options = b'\340A\001'
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['file_media_type']._options = None
  _SIMILARITYCHUNKSSEARCHREQUEST.fields_by_name['file_media_type']._serialized_options = b'\340A\001'
  _SIMILARITYCHUNKSSEARCHRESPONSE.fields_by_name['similar_chunks']._options = None
  _SIMILARITYCHUNKSSEARCHRESPONSE.fields_by_name['similar_chunks']._serialized_options = b'\340A\003'
  _SIMILARITYCHUNK.fields_by_name['chunk_uid']._options = None
  _SIMILARITYCHUNK.fields_by_name['chunk_uid']._serialized_options = b'\340A\003'
  _SIMILARITYCHUNK.fields_by_name['similarity_score']._options = None
  _SIMILARITYCHUNK.fields_by_name['similarity_score']._serialized_options = b'\340A\003'
  _SIMILARITYCHUNK.fields_by_name['text_content']._options = None
  _SIMILARITYCHUNK.fields_by_name['text_content']._serialized_options = b'\340A\003'
  _SIMILARITYCHUNK.fields_by_name['source_file']._options = None
  _SIMILARITYCHUNK.fields_by_name['source_file']._serialized_options = b'\340A\003'
  _SIMILARITYCHUNK.fields_by_name['chunk_metadata']._options = None
  _SIMILARITYCHUNK.fields_by_name['chunk_metadata']._serialized_options = b'\340A\003'
  _globals['_FILEMEDIATYPE']._serialized_start=2754
  _globals['_FILEMEDIATYPE']._serialized_end=2913
  _globals['_CONTENTTYPE']._serialized_start=2915
  _globals['_CONTENTTYPE']._serialized_end=3036
  _globals['_CHUNK']._serialized_start=135
  _globals['_CHUNK']._serialized_end=503
  _globals['_LISTCHUNKSREQUEST']._serialized_start=505
  _globals['_LISTCHUNKSREQUEST']._serialized_end=632
  _globals['_LISTCHUNKSRESPONSE']._serialized_start=634
  _globals['_LISTCHUNKSRESPONSE']._serialized_end=717
  _globals['_SEARCHCHUNKSREQUEST']._serialized_start=719
  _globals['_SEARCHCHUNKSREQUEST']._serialized_end=816
  _globals['_SEARCHCHUNKSRESPONSE']._serialized_start=818
  _globals['_SEARCHCHUNKSRESPONSE']._serialized_end=903
  _globals['_SOURCEFILE']._serialized_start=906
  _globals['_SOURCEFILE']._serialized_end=1181
  _globals['_GETSOURCEFILEREQUEST']._serialized_start=1184
  _globals['_GETSOURCEFILEREQUEST']._serialized_end=1314
  _globals['_GETSOURCEFILERESPONSE']._serialized_start=1316
  _globals['_GETSOURCEFILERESPONSE']._serialized_end=1416
  _globals['_GETFILESUMMARYREQUEST']._serialized_start=1419
  _globals['_GETFILESUMMARYREQUEST']._serialized_end=1550
  _globals['_GETFILESUMMARYRESPONSE']._serialized_start=1552
  _globals['_GETFILESUMMARYRESPONSE']._serialized_end=1607
  _globals['_SEARCHSOURCEFILESREQUEST']._serialized_start=1609
  _globals['_SEARCHSOURCEFILESREQUEST']._serialized_end=1709
  _globals['_SEARCHSOURCEFILESRESPONSE']._serialized_start=1711
  _globals['_SEARCHSOURCEFILESRESPONSE']._serialized_end=1817
  _globals['_UPDATECHUNKREQUEST']._serialized_start=1819
  _globals['_UPDATECHUNKREQUEST']._serialized_end=1912
  _globals['_UPDATECHUNKRESPONSE']._serialized_start=1914
  _globals['_UPDATECHUNKRESPONSE']._serialized_end=1996
  _globals['_SIMILARITYCHUNKSSEARCHREQUEST']._serialized_start=1999
  _globals['_SIMILARITYCHUNKSSEARCHREQUEST']._serialized_end=2371
  _globals['_SIMILARITYCHUNKSSEARCHRESPONSE']._serialized_start=2373
  _globals['_SIMILARITYCHUNKSSEARCHRESPONSE']._serialized_end=2493
  _globals['_SIMILARITYCHUNK']._serialized_start=2496
  _globals['_SIMILARITYCHUNK']._serialized_end=2751
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from model.ray.v1alpha import user_defined_pb2 as model_dot_ray_dot_v1alpha_dot_user__defined__pb2


class UserDefinedServiceStub(object):
    """User defined service for internal process
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.__call__ = channel.unary_unary(
                '/model.ray.v1alpha.UserDefinedService/__call__',
                request_serializer=model_dot_ray_dot_v1alpha_dot_user__defined__pb2.CallRequest.SerializeToString,
                response_deserializer=model_dot_ray_dot_v1alpha_dot_user__defined__pb2.CallResponse.FromString,
                )


class UserDefinedServiceServicer(object):
    """User defined service for internal process
    """

    def __call__(self, request, context):
        """Trigger method is the default trigger entry for ray deployment
        Ray doesn't comply with the naming convention of protobuf, so we need to
        buf:lint:ignore RPC_PASCAL_CASE
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserDefinedServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            '__call__': grpc.unary_unary_rpc_method_handler(
                    servicer.__call__,
                    request_deserializer=model_dot_ray_dot_v1alpha_dot_user__defined__pb2.CallRequest.FromString,
                    response_serializer=model_dot_ray_dot_v1alpha_dot_user__defined__pb2.CallResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'model.ray.v1alpha.UserDefinedService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserDefinedService(object):
    """User defined service for internal process
    """

    @staticmethod
    def __call__(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.ray.v1alpha.UserDefinedService/__call__',
            model_dot_ray_dot_v1alpha_dot_user__defined__pb2.CallRequest.SerializeToString,
            model_dot_ray_dot_v1alpha_dot_user__defined__pb2.CallResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from model.ray import serve_pb2 as model_dot_ray_dot_serve__pb2


class RayServeAPIServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListApplications = channel.unary_unary(
                '/ray.serve.RayServeAPIService/ListApplications',
                request_serializer=model_dot_ray_dot_serve__pb2.ListApplicationsRequest.SerializeToString,
                response_deserializer=model_dot_ray_dot_serve__pb2.ListApplicationsResponse.FromString,
                )
        self.Healthz = channel.unary_unary(
                '/ray.serve.RayServeAPIService/Healthz',
                request_serializer=model_dot_ray_dot_serve__pb2.HealthzRequest.SerializeToString,
                response_deserializer=model_dot_ray_dot_serve__pb2.HealthzResponse.FromString,
                )


class RayServeAPIServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListApplications(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Healthz(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RayServeAPIServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListApplications': grpc.unary_unary_rpc_method_handler(
                    servicer.ListApplications,
                    request_deserializer=model_dot_ray_dot_serve__pb2.ListApplicationsRequest.FromString,
                    response_serializer=model_dot_ray_dot_serve__pb2.ListApplicationsResponse.SerializeToString,
            ),
            'Healthz': grpc.unary_unary_rpc_method_handler(
                    servicer.Healthz,
                    request_deserializer=model_dot_ray_dot_serve__pb2.HealthzRequest.FromString,
                    response_serializer=model_dot_ray_dot_serve__pb2.HealthzResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ray.serve.RayServeAPIService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RayServeAPIService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListApplications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ray.serve.RayServeAPIService/ListApplications',
            model_dot_ray_dot_serve__pb2.ListApplicationsRequest.SerializeToString,
            model_dot_ray_dot_serve__pb2.ListApplicationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Healthz(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ray.serve.RayServeAPIService/Healthz',
            model_dot_ray_dot_serve__pb2.HealthzRequest.SerializeToString,
            model_dot_ray_dot_serve__pb2.HealthzResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class UserDefinedServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.__call__ = channel.unary_unary(
                '/ray.serve.UserDefinedService/__call__',
                request_serializer=model_dot_ray_dot_serve__pb2.UserDefinedMessage.SerializeToString,
                response_deserializer=model_dot_ray_dot_serve__pb2.UserDefinedResponse.FromString,
                )
        self.Method1 = channel.unary_unary(
                '/ray.serve.UserDefinedService/Method1',
                request_serializer=model_dot_ray_dot_serve__pb2.UserDefinedMessage.SerializeToString,
                response_deserializer=model_dot_ray_dot_serve__pb2.UserDefinedResponse.FromString,
                )
        self.Method2 = channel.unary_unary(
                '/ray.serve.UserDefinedService/Method2',
                request_serializer=model_dot_ray_dot_serve__pb2.UserDefinedMessage2.SerializeToString,
                response_deserializer=model_dot_ray_dot_serve__pb2.UserDefinedResponse2.FromString,
                )
        self.Streaming = channel.unary_stream(
                '/ray.serve.UserDefinedService/Streaming',
                request_serializer=model_dot_ray_dot_serve__pb2.UserDefinedMessage.SerializeToString,
                response_deserializer=model_dot_ray_dot_serve__pb2.UserDefinedResponse.FromString,
                )


class UserDefinedServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def __call__(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Method1(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Method2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Streaming(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserDefinedServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            '__call__': grpc.unary_unary_rpc_method_handler(
                    servicer.__call__,
                    request_deserializer=model_dot_ray_dot_serve__pb2.UserDefinedMessage.FromString,
                    response_serializer=model_dot_ray_dot_serve__pb2.UserDefinedResponse.SerializeToString,
            ),
            'Method1': grpc.unary_unary_rpc_method_handler(
                    servicer.Method1,
                    request_deserializer=model_dot_ray_dot_serve__pb2.UserDefinedMessage.FromString,
                    response_serializer=model_dot_ray_dot_serve__pb2.UserDefinedResponse.SerializeToString,
            ),
            'Method2': grpc.unary_unary_rpc_method_handler(
                    servicer.Method2,
                    request_deserializer=model_dot_ray_dot_serve__pb2.UserDefinedMessage2.FromString,
                    response_serializer=model_dot_ray_dot_serve__pb2.UserDefinedResponse2.SerializeToString,
            ),
            'Streaming': grpc.unary_stream_rpc_method_handler(
                    servicer.Streaming,
                    request_deserializer=model_dot_ray_dot_serve__pb2.UserDefinedMessage.FromString,
                    response_serializer=model_dot_ray_dot_serve__pb2.UserDefinedResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ray.serve.UserDefinedService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserDefinedService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def __call__(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ray.serve.UserDefinedService/__call__',
            model_dot_ray_dot_serve__pb2.UserDefinedMessage.SerializeToString,
            model_dot_ray_dot_serve__pb2.UserDefinedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Method1(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ray.serve.UserDefinedService/Method1',
            model_dot_ray_dot_serve__pb2.UserDefinedMessage.SerializeToString,
            model_dot_ray_dot_serve__pb2.UserDefinedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Method2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ray.serve.UserDefinedService/Method2',
            model_dot_ray_dot_serve__pb2.UserDefinedMessage2.SerializeToString,
            model_dot_ray_dot_serve__pb2.UserDefinedResponse2.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Streaming(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ray.serve.UserDefinedService/Streaming',
            model_dot_ray_dot_serve__pb2.UserDefinedMessage.SerializeToString,
            model_dot_ray_dot_serve__pb2.UserDefinedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class FruitServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FruitStand = channel.unary_unary(
                '/ray.serve.FruitService/FruitStand',
                request_serializer=model_dot_ray_dot_serve__pb2.FruitAmounts.SerializeToString,
                response_deserializer=model_dot_ray_dot_serve__pb2.FruitCosts.FromString,
                )


class FruitServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def FruitStand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FruitServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FruitStand': grpc.unary_unary_rpc_method_handler(
                    servicer.FruitStand,
                    request_deserializer=model_dot_ray_dot_serve__pb2.FruitAmounts.FromString,
                    response_serializer=model_dot_ray_dot_serve__pb2.FruitCosts.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ray.serve.FruitService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FruitService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def FruitStand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ray.serve.FruitService/FruitStand',
            model_dot_ray_dot_serve__pb2.FruitAmounts.SerializeToString,
            model_dot_ray_dot_serve__pb2.FruitCosts.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class RayServeBenchmarkServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.grpc_call = channel.unary_unary(
                '/ray.serve.RayServeBenchmarkService/grpc_call',
                request_serializer=model_dot_ray_dot_serve__pb2.ArrayData.SerializeToString,
                response_deserializer=model_dot_ray_dot_serve__pb2.ModelOutput.FromString,
                )
        self.call_with_string = channel.unary_unary(
                '/ray.serve.RayServeBenchmarkService/call_with_string',
                request_serializer=model_dot_ray_dot_serve__pb2.StringData.SerializeToString,
                response_deserializer=model_dot_ray_dot_serve__pb2.ModelOutput.FromString,
                )


class RayServeBenchmarkServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def grpc_call(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def call_with_string(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RayServeBenchmarkServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'grpc_call': grpc.unary_unary_rpc_method_handler(
                    servicer.grpc_call,
                    request_deserializer=model_dot_ray_dot_serve__pb2.ArrayData.FromString,
                    response_serializer=model_dot_ray_dot_serve__pb2.ModelOutput.SerializeToString,
            ),
            'call_with_string': grpc.unary_unary_rpc_method_handler(
                    servicer.call_with_string,
                    request_deserializer=model_dot_ray_dot_serve__pb2.StringData.FromString,
                    response_serializer=model_dot_ray_dot_serve__pb2.ModelOutput.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ray.serve.RayServeBenchmarkService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RayServeBenchmarkService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def grpc_call(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ray.serve.RayServeBenchmarkService/grpc_call',
            model_dot_ray_dot_serve__pb2.ArrayData.SerializeToString,
            model_dot_ray_dot_serve__pb2.ModelOutput.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def call_with_string(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ray.serve.RayServeBenchmarkService/call_with_string',
            model_dot_ray_dot_serve__pb2.StringData.SerializeToString,
            model_dot_ray_dot_serve__pb2.ModelOutput.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2017 The Ray Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _EncodingType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EncodingTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EncodingType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TEXT: _EncodingType.ValueType  # 0
    JSON: _EncodingType.ValueType  # 1

class EncodingType(_EncodingType, metaclass=_EncodingTypeEnumTypeWrapper):
    """[Begin] LOGGING CONFIG
    Encoding type
    """

TEXT: EncodingType.ValueType  # 0
JSON: EncodingType.ValueType  # 1
global___EncodingType = EncodingType

class _DeploymentLanguage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeploymentLanguageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeploymentLanguage.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PYTHON: _DeploymentLanguage.ValueType  # 0
    JAVA: _DeploymentLanguage.ValueType  # 1

class DeploymentLanguage(_DeploymentLanguage, metaclass=_DeploymentLanguageEnumTypeWrapper):
    """Deployment language."""

PYTHON: DeploymentLanguage.ValueType  # 0
JAVA: DeploymentLanguage.ValueType  # 1
global___DeploymentLanguage = DeploymentLanguage

class _TargetCapacityDirection:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TargetCapacityDirectionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TargetCapacityDirection.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNSET: _TargetCapacityDirection.ValueType  # 0
    UP: _TargetCapacityDirection.ValueType  # 1
    DOWN: _TargetCapacityDirection.ValueType  # 2

class TargetCapacityDirection(_TargetCapacityDirection, metaclass=_TargetCapacityDirectionEnumTypeWrapper): ...

UNSET: TargetCapacityDirection.ValueType  # 0
UP: TargetCapacityDirection.ValueType  # 1
DOWN: TargetCapacityDirection.ValueType  # 2
global___TargetCapacityDirection = TargetCapacityDirection

class _DeploymentStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeploymentStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeploymentStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEPLOYMENT_STATUS_UPDATING: _DeploymentStatus.ValueType  # 0
    """Keep frontend code of ServeDeploymentStatus in
    dashboard/client/src/type/serve.ts in sync with this enum
    """
    DEPLOYMENT_STATUS_HEALTHY: _DeploymentStatus.ValueType  # 1
    DEPLOYMENT_STATUS_UNHEALTHY: _DeploymentStatus.ValueType  # 2
    DEPLOYMENT_STATUS_DEPLOY_FAILED: _DeploymentStatus.ValueType  # 3
    DEPLOYMENT_STATUS_UPSCALING: _DeploymentStatus.ValueType  # 4
    DEPLOYMENT_STATUS_DOWNSCALING: _DeploymentStatus.ValueType  # 5

class DeploymentStatus(_DeploymentStatus, metaclass=_DeploymentStatusEnumTypeWrapper): ...

DEPLOYMENT_STATUS_UPDATING: DeploymentStatus.ValueType  # 0
"""Keep frontend code of ServeDeploymentStatus in
dashboard/client/src/type/serve.ts in sync with this enum
"""
DEPLOYMENT_STATUS_HEALTHY: DeploymentStatus.ValueType  # 1
DEPLOYMENT_STATUS_UNHEALTHY: DeploymentStatus.ValueType  # 2
DEPLOYMENT_STATUS_DEPLOY_FAILED: DeploymentStatus.ValueType  # 3
DEPLOYMENT_STATUS_UPSCALING: DeploymentStatus.ValueType  # 4
DEPLOYMENT_STATUS_DOWNSCALING: DeploymentStatus.ValueType  # 5
global___DeploymentStatus = DeploymentStatus

class _DeploymentStatusTrigger:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeploymentStatusTriggerEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeploymentStatusTrigger.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEPLOYMENT_STATUS_TRIGGER_UNSPECIFIED: _DeploymentStatusTrigger.ValueType  # 0
    DEPLOYMENT_STATUS_TRIGGER_CONFIG_UPDATE_STARTED: _DeploymentStatusTrigger.ValueType  # 1
    DEPLOYMENT_STATUS_TRIGGER_CONFIG_UPDATE_COMPLETED: _DeploymentStatusTrigger.ValueType  # 2
    DEPLOYMENT_STATUS_TRIGGER_UPSCALE_COMPLETED: _DeploymentStatusTrigger.ValueType  # 3
    DEPLOYMENT_STATUS_TRIGGER_DOWNSCALE_COMPLETED: _DeploymentStatusTrigger.ValueType  # 4
    DEPLOYMENT_STATUS_TRIGGER_AUTOSCALING: _DeploymentStatusTrigger.ValueType  # 5
    DEPLOYMENT_STATUS_TRIGGER_REPLICA_STARTUP_FAILED: _DeploymentStatusTrigger.ValueType  # 6
    DEPLOYMENT_STATUS_TRIGGER_HEALTH_CHECK_FAILED: _DeploymentStatusTrigger.ValueType  # 7
    DEPLOYMENT_STATUS_TRIGGER_INTERNAL_ERROR: _DeploymentStatusTrigger.ValueType  # 8
    DEPLOYMENT_STATUS_TRIGGER_DELETING: _DeploymentStatusTrigger.ValueType  # 9

class DeploymentStatusTrigger(_DeploymentStatusTrigger, metaclass=_DeploymentStatusTriggerEnumTypeWrapper): ...

DEPLOYMENT_STATUS_TRIGGER_UNSPECIFIED: DeploymentStatusTrigger.ValueType  # 0
DEPLOYMENT_STATUS_TRIGGER_CONFIG_UPDATE_STARTED: DeploymentStatusTrigger.ValueType  # 1
DEPLOYMENT_STATUS_TRIGGER_CONFIG_UPDATE_COMPLETED: DeploymentStatusTrigger.ValueType  # 2
DEPLOYMENT_STATUS_TRIGGER_UPSCALE_COMPLETED: DeploymentStatusTrigger.ValueType  # 3
DEPLOYMENT_STATUS_TRIGGER_DOWNSCALE_COMPLETED: DeploymentStatusTrigger.ValueType  # 4
DEPLOYMENT_STATUS_TRIGGER_AUTOSCALING: DeploymentStatusTrigger.ValueType  # 5
DEPLOYMENT_STATUS_TRIGGER_REPLICA_STARTUP_FAILED: DeploymentStatusTrigger.ValueType  # 6
DEPLOYMENT_STATUS_TRIGGER_HEALTH_CHECK_FAILED: DeploymentStatusTrigger.ValueType  # 7
DEPLOYMENT_STATUS_TRIGGER_INTERNAL_ERROR: DeploymentStatusTrigger.ValueType  # 8
DEPLOYMENT_STATUS_TRIGGER_DELETING: DeploymentStatusTrigger.ValueType  # 9
global___DeploymentStatusTrigger = DeploymentStatusTrigger

class _ApplicationStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ApplicationStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ApplicationStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    APPLICATION_STATUS_DEPLOYING: _ApplicationStatus.ValueType  # 0
    """Keep frontend code of ServeApplicationStatus in
    dashboard/client/src/type/serve.ts in sync with this enum
    """
    APPLICATION_STATUS_RUNNING: _ApplicationStatus.ValueType  # 1
    APPLICATION_STATUS_DEPLOY_FAILED: _ApplicationStatus.ValueType  # 2
    APPLICATION_STATUS_DELETING: _ApplicationStatus.ValueType  # 3
    APPLICATION_STATUS_NOT_STARTED: _ApplicationStatus.ValueType  # 5
    APPLICATION_STATUS_UNHEALTHY: _ApplicationStatus.ValueType  # 6

class ApplicationStatus(_ApplicationStatus, metaclass=_ApplicationStatusEnumTypeWrapper): ...

APPLICATION_STATUS_DEPLOYING: ApplicationStatus.ValueType  # 0
"""Keep frontend code of ServeApplicationStatus in
dashboard/client/src/type/serve.ts in sync with this enum
"""
APPLICATION_STATUS_RUNNING: ApplicationStatus.ValueType  # 1
APPLICATION_STATUS_DEPLOY_FAILED: ApplicationStatus.ValueType  # 2
APPLICATION_STATUS_DELETING: ApplicationStatus.ValueType  # 3
APPLICATION_STATUS_NOT_STARTED: ApplicationStatus.ValueType  # 5
APPLICATION_STATUS_UNHEALTHY: ApplicationStatus.ValueType  # 6
global___ApplicationStatus = ApplicationStatus

@typing_extensions.final
class AutoscalingConfig(google.protobuf.message.Message):
    """Configuration options for Serve's replica autoscaler."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_REPLICAS_FIELD_NUMBER: builtins.int
    MAX_REPLICAS_FIELD_NUMBER: builtins.int
    METRICS_INTERVAL_S_FIELD_NUMBER: builtins.int
    LOOK_BACK_PERIOD_S_FIELD_NUMBER: builtins.int
    SMOOTHING_FACTOR_FIELD_NUMBER: builtins.int
    DOWNSCALE_DELAY_S_FIELD_NUMBER: builtins.int
    UPSCALE_DELAY_S_FIELD_NUMBER: builtins.int
    INITIAL_REPLICAS_FIELD_NUMBER: builtins.int
    UPSCALE_SMOOTHING_FACTOR_FIELD_NUMBER: builtins.int
    DOWNSCALE_SMOOTHING_FACTOR_FIELD_NUMBER: builtins.int
    _SERIALIZED_POLICY_DEF_FIELD_NUMBER: builtins.int
    _POLICY_FIELD_NUMBER: builtins.int
    TARGET_ONGOING_REQUESTS_FIELD_NUMBER: builtins.int
    UPSCALING_FACTOR_FIELD_NUMBER: builtins.int
    DOWNSCALING_FACTOR_FIELD_NUMBER: builtins.int
    min_replicas: builtins.int
    """Minimal number of replicas, must be a non-negative integer."""
    max_replicas: builtins.int
    """Maximal number of replicas, must be a non-negative integer and greater or
    equals to min_replicas.
    """
    metrics_interval_s: builtins.float
    """The frequency of how long does each replica sending metrics to autoscaler."""
    look_back_period_s: builtins.float
    """The window (in seconds) for autoscaler to calculate rolling average of
    metrics on.
    """
    smoothing_factor: builtins.float
    """[DEPRECATED] Use `upscaling_factor` and/or `downscaling_factor` instead."""
    downscale_delay_s: builtins.float
    """How long to wait before scaling down replicas."""
    upscale_delay_s: builtins.float
    """How long to wait before scaling up replicas."""
    initial_replicas: builtins.int
    """Initial number of replicas deployment should start with. Must be
    non-negative.
    """
    upscale_smoothing_factor: builtins.float
    """[DEPRECATED] Use `upscaling_factor` instead."""
    downscale_smoothing_factor: builtins.float
    """[DEPRECATED] Use `downscaling_factor` instead."""
    _serialized_policy_def: builtins.bytes
    """The cloudpickled policy definition."""
    _policy: builtins.str
    """The import path of the policy if user passed a string. Will be the
    concatenation of the policy module and the policy name if user passed a
    callable.
    """
    target_ongoing_requests: builtins.float
    """Target number of in flight requests per replica. This is the primary
    configuration knob for replica autoscaler. Lower the number, the more
    rapidly the replicas scales up. Must be a non-negative integer.
    """
    upscaling_factor: builtins.float
    """The multiplicative "gain" factor to limit upscale."""
    downscaling_factor: builtins.float
    """The multiplicative "gain" factor to limit downscale."""
    def __init__(
        self,
        *,
        min_replicas: builtins.int = ...,
        max_replicas: builtins.int = ...,
        metrics_interval_s: builtins.float = ...,
        look_back_period_s: builtins.float = ...,
        smoothing_factor: builtins.float = ...,
        downscale_delay_s: builtins.float = ...,
        upscale_delay_s: builtins.float = ...,
        initial_replicas: builtins.int | None = ...,
        upscale_smoothing_factor: builtins.float | None = ...,
        downscale_smoothing_factor: builtins.float | None = ...,
        _serialized_policy_def: builtins.bytes = ...,
        _policy: builtins.str = ...,
        target_ongoing_requests: builtins.float = ...,
        upscaling_factor: builtins.float | None = ...,
        downscaling_factor: builtins.float | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_downscale_smoothing_factor", b"_downscale_smoothing_factor", "_downscaling_factor", b"_downscaling_factor", "_initial_replicas", b"_initial_replicas", "_upscale_smoothing_factor", b"_upscale_smoothing_factor", "_upscaling_factor", b"_upscaling_factor", "downscale_smoothing_factor", b"downscale_smoothing_factor", "downscaling_factor", b"downscaling_factor", "initial_replicas", b"initial_replicas", "upscale_smoothing_factor", b"upscale_smoothing_factor", "upscaling_factor", b"upscaling_factor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_downscale_smoothing_factor", b"_downscale_smoothing_factor", "_downscaling_factor", b"_downscaling_factor", "_initial_replicas", b"_initial_replicas", "_policy", b"_policy", "_serialized_policy_def", b"_serialized_policy_def", "_upscale_smoothing_factor", b"_upscale_smoothing_factor", "_upscaling_factor", b"_upscaling_factor", "downscale_delay_s", b"downscale_delay_s", "downscale_smoothing_factor", b"downscale_smoothing_factor", "downscaling_factor", b"downscaling_factor", "initial_replicas", b"initial_replicas", "look_back_period_s", b"look_back_period_s", "max_replicas", b"max_replicas", "metrics_interval_s", b"metrics_interval_s", "min_replicas", b"min_replicas", "smoothing_factor", b"smoothing_factor", "target_ongoing_requests", b"target_ongoing_requests", "upscale_delay_s", b"upscale_delay_s", "upscale_smoothing_factor", b"upscale_smoothing_factor", "upscaling_factor", b"upscaling_factor"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_downscale_smoothing_factor", b"_downscale_smoothing_factor"]) -> typing_extensions.Literal["downscale_smoothing_factor"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_downscaling_factor", b"_downscaling_factor"]) -> typing_extensions.Literal["downscaling_factor"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_initial_replicas", b"_initial_replicas"]) -> typing_extensions.Literal["initial_replicas"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_upscale_smoothing_factor", b"_upscale_smoothing_factor"]) -> typing_extensions.Literal["upscale_smoothing_factor"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_upscaling_factor", b"_upscaling_factor"]) -> typing_extensions.Literal["upscaling_factor"] | None: ...

global___AutoscalingConfig = AutoscalingConfig

@typing_extensions.final
class LoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCODING_FIELD_NUMBER: builtins.int
    LOG_LEVEL_FIELD_NUMBER: builtins.int
    LOGS_DIR_FIELD_NUMBER: builtins.int
    ENABLE_ACCESS_LOG_FIELD_NUMBER: builtins.int
    ADDITIONAL_LOG_STANDARD_ATTRS_FIELD_NUMBER: builtins.int
    encoding: global___EncodingType.ValueType
    log_level: builtins.str
    logs_dir: builtins.str
    enable_access_log: builtins.bool
    @property
    def additional_log_standard_attrs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        encoding: global___EncodingType.ValueType = ...,
        log_level: builtins.str = ...,
        logs_dir: builtins.str = ...,
        enable_access_log: builtins.bool = ...,
        additional_log_standard_attrs: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_log_standard_attrs", b"additional_log_standard_attrs", "enable_access_log", b"enable_access_log", "encoding", b"encoding", "log_level", b"log_level", "logs_dir", b"logs_dir"]) -> None: ...

global___LoggingConfig = LoggingConfig

@typing_extensions.final
class DeploymentConfig(google.protobuf.message.Message):
    """[End] Logging Config

    Configuration options for a deployment, to be set by the user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_REPLICAS_FIELD_NUMBER: builtins.int
    MAX_ONGOING_REQUESTS_FIELD_NUMBER: builtins.int
    MAX_QUEUED_REQUESTS_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    GRACEFUL_SHUTDOWN_WAIT_LOOP_S_FIELD_NUMBER: builtins.int
    GRACEFUL_SHUTDOWN_TIMEOUT_S_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_PERIOD_S_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_TIMEOUT_S_FIELD_NUMBER: builtins.int
    IS_CROSS_LANGUAGE_FIELD_NUMBER: builtins.int
    DEPLOYMENT_LANGUAGE_FIELD_NUMBER: builtins.int
    AUTOSCALING_CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    USER_CONFIGURED_OPTION_NAMES_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    num_replicas: builtins.int
    """The number of processes to start up that will handle requests to this
    deployment.
    """
    max_ongoing_requests: builtins.int
    """The maximum number of queries that will be sent to a replica of this
    deployment without receiving a response.
    """
    max_queued_requests: builtins.int
    """The maximum number of requests that will be queued in deployment handles."""
    user_config: builtins.bytes
    """Arguments to pass to the reconfigure method of the deployment. The
    reconfigure method is called if user_config is not None.
    """
    graceful_shutdown_wait_loop_s: builtins.float
    """Duration that deployment replicas will wait until there is no more work to
    be done before shutting down.
    """
    graceful_shutdown_timeout_s: builtins.float
    """Controller waits for this duration to forcefully kill the replica for
    shutdown.
    """
    health_check_period_s: builtins.float
    """Frequency at which the controller health checks replicas."""
    health_check_timeout_s: builtins.float
    """Timeout after which a replica is marked unhealthy without a response."""
    is_cross_language: builtins.bool
    """Is the construction of deployment is cross language?"""
    deployment_language: global___DeploymentLanguage.ValueType
    """The deployment's programming language."""
    @property
    def autoscaling_config(self) -> global___AutoscalingConfig:
        """The deployment's autoscaling configuration."""
    version: builtins.str
    @property
    def user_configured_option_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def logging_config(self) -> global___LoggingConfig: ...
    def __init__(
        self,
        *,
        num_replicas: builtins.int = ...,
        max_ongoing_requests: builtins.int = ...,
        max_queued_requests: builtins.int = ...,
        user_config: builtins.bytes = ...,
        graceful_shutdown_wait_loop_s: builtins.float = ...,
        graceful_shutdown_timeout_s: builtins.float = ...,
        health_check_period_s: builtins.float = ...,
        health_check_timeout_s: builtins.float = ...,
        is_cross_language: builtins.bool = ...,
        deployment_language: global___DeploymentLanguage.ValueType = ...,
        autoscaling_config: global___AutoscalingConfig | None = ...,
        version: builtins.str = ...,
        user_configured_option_names: collections.abc.Iterable[builtins.str] | None = ...,
        logging_config: global___LoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling_config", b"autoscaling_config", "logging_config", b"logging_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscaling_config", b"autoscaling_config", "deployment_language", b"deployment_language", "graceful_shutdown_timeout_s", b"graceful_shutdown_timeout_s", "graceful_shutdown_wait_loop_s", b"graceful_shutdown_wait_loop_s", "health_check_period_s", b"health_check_period_s", "health_check_timeout_s", b"health_check_timeout_s", "is_cross_language", b"is_cross_language", "logging_config", b"logging_config", "max_ongoing_requests", b"max_ongoing_requests", "max_queued_requests", b"max_queued_requests", "num_replicas", b"num_replicas", "user_config", b"user_config", "user_configured_option_names", b"user_configured_option_names", "version", b"version"]) -> None: ...

global___DeploymentConfig = DeploymentConfig

@typing_extensions.final
class RequestMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ContextEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    REQUEST_ID_FIELD_NUMBER: builtins.int
    INTERNAL_REQUEST_ID_FIELD_NUMBER: builtins.int
    CALL_METHOD_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    MULTIPLEXED_MODEL_ID_FIELD_NUMBER: builtins.int
    ROUTE_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    internal_request_id: builtins.str
    call_method: builtins.str
    @property
    def context(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    multiplexed_model_id: builtins.str
    route: builtins.str
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        internal_request_id: builtins.str = ...,
        call_method: builtins.str = ...,
        context: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        multiplexed_model_id: builtins.str = ...,
        route: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_method", b"call_method", "context", b"context", "internal_request_id", b"internal_request_id", "multiplexed_model_id", b"multiplexed_model_id", "request_id", b"request_id", "route", b"route"]) -> None: ...

global___RequestMetadata = RequestMetadata

@typing_extensions.final
class RequestWrapper(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BODY_FIELD_NUMBER: builtins.int
    body: builtins.bytes
    def __init__(
        self,
        *,
        body: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body"]) -> None: ...

global___RequestWrapper = RequestWrapper

@typing_extensions.final
class UpdatedObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_SNAPSHOT_FIELD_NUMBER: builtins.int
    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    object_snapshot: builtins.bytes
    snapshot_id: builtins.int
    def __init__(
        self,
        *,
        object_snapshot: builtins.bytes = ...,
        snapshot_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_snapshot", b"object_snapshot", "snapshot_id", b"snapshot_id"]) -> None: ...

global___UpdatedObject = UpdatedObject

@typing_extensions.final
class LongPollRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class KeysToSnapshotIdsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    KEYS_TO_SNAPSHOT_IDS_FIELD_NUMBER: builtins.int
    @property
    def keys_to_snapshot_ids(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]: ...
    def __init__(
        self,
        *,
        keys_to_snapshot_ids: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["keys_to_snapshot_ids", b"keys_to_snapshot_ids"]) -> None: ...

global___LongPollRequest = LongPollRequest

@typing_extensions.final
class LongPollResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UpdatedObjectsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___UpdatedObject: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___UpdatedObject | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    UPDATED_OBJECTS_FIELD_NUMBER: builtins.int
    @property
    def updated_objects(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___UpdatedObject]: ...
    def __init__(
        self,
        *,
        updated_objects: collections.abc.Mapping[builtins.str, global___UpdatedObject] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["updated_objects", b"updated_objects"]) -> None: ...

global___LongPollResult = LongPollResult

@typing_extensions.final
class EndpointInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENDPOINT_NAME_FIELD_NUMBER: builtins.int
    ROUTE_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    endpoint_name: builtins.str
    route: builtins.str
    @property
    def config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        endpoint_name: builtins.str = ...,
        route: builtins.str = ...,
        config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "endpoint_name", b"endpoint_name", "route", b"route"]) -> None: ...

global___EndpointInfo = EndpointInfo

@typing_extensions.final
class EndpointSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class EndpointsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___EndpointInfo: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___EndpointInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENDPOINTS_FIELD_NUMBER: builtins.int
    @property
    def endpoints(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___EndpointInfo]: ...
    def __init__(
        self,
        *,
        endpoints: collections.abc.Mapping[builtins.str, global___EndpointInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoints", b"endpoints"]) -> None: ...

global___EndpointSet = EndpointSet

@typing_extensions.final
class ActorNameList(google.protobuf.message.Message):
    """Now Actor handle can be transfered across language through ray call, but the
    list of Actor handles can't. So we use this message wrapped a Actor name list
    to pass actor list across language. When Actor handle list supports across
    language, this message can be replaced.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMES_FIELD_NUMBER: builtins.int
    @property
    def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["names", b"names"]) -> None: ...

global___ActorNameList = ActorNameList

@typing_extensions.final
class DeploymentTargetInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLICA_NAMES_FIELD_NUMBER: builtins.int
    IS_AVAILABLE_FIELD_NUMBER: builtins.int
    @property
    def replica_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_available: builtins.bool
    def __init__(
        self,
        *,
        replica_names: collections.abc.Iterable[builtins.str] | None = ...,
        is_available: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_available", b"is_available", "replica_names", b"replica_names"]) -> None: ...

global___DeploymentTargetInfo = DeploymentTargetInfo

@typing_extensions.final
class DeploymentVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_VERSION_FIELD_NUMBER: builtins.int
    DEPLOYMENT_CONFIG_FIELD_NUMBER: builtins.int
    RAY_ACTOR_OPTIONS_FIELD_NUMBER: builtins.int
    PLACEMENT_GROUP_BUNDLES_FIELD_NUMBER: builtins.int
    PLACEMENT_GROUP_STRATEGY_FIELD_NUMBER: builtins.int
    MAX_REPLICAS_PER_NODE_FIELD_NUMBER: builtins.int
    code_version: builtins.str
    @property
    def deployment_config(self) -> global___DeploymentConfig: ...
    ray_actor_options: builtins.str
    placement_group_bundles: builtins.str
    placement_group_strategy: builtins.str
    max_replicas_per_node: builtins.int
    def __init__(
        self,
        *,
        code_version: builtins.str = ...,
        deployment_config: global___DeploymentConfig | None = ...,
        ray_actor_options: builtins.str = ...,
        placement_group_bundles: builtins.str = ...,
        placement_group_strategy: builtins.str = ...,
        max_replicas_per_node: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment_config", b"deployment_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code_version", b"code_version", "deployment_config", b"deployment_config", "max_replicas_per_node", b"max_replicas_per_node", "placement_group_bundles", b"placement_group_bundles", "placement_group_strategy", b"placement_group_strategy", "ray_actor_options", b"ray_actor_options"]) -> None: ...

global___DeploymentVersion = DeploymentVersion

@typing_extensions.final
class ReplicaConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_DEF_NAME_FIELD_NUMBER: builtins.int
    DEPLOYMENT_DEF_FIELD_NUMBER: builtins.int
    INIT_ARGS_FIELD_NUMBER: builtins.int
    INIT_KWARGS_FIELD_NUMBER: builtins.int
    RAY_ACTOR_OPTIONS_FIELD_NUMBER: builtins.int
    PLACEMENT_GROUP_BUNDLES_FIELD_NUMBER: builtins.int
    PLACEMENT_GROUP_STRATEGY_FIELD_NUMBER: builtins.int
    MAX_REPLICAS_PER_NODE_FIELD_NUMBER: builtins.int
    deployment_def_name: builtins.str
    deployment_def: builtins.bytes
    init_args: builtins.bytes
    init_kwargs: builtins.bytes
    ray_actor_options: builtins.str
    placement_group_bundles: builtins.str
    placement_group_strategy: builtins.str
    max_replicas_per_node: builtins.int
    def __init__(
        self,
        *,
        deployment_def_name: builtins.str = ...,
        deployment_def: builtins.bytes = ...,
        init_args: builtins.bytes = ...,
        init_kwargs: builtins.bytes = ...,
        ray_actor_options: builtins.str = ...,
        placement_group_bundles: builtins.str = ...,
        placement_group_strategy: builtins.str = ...,
        max_replicas_per_node: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_def", b"deployment_def", "deployment_def_name", b"deployment_def_name", "init_args", b"init_args", "init_kwargs", b"init_kwargs", "max_replicas_per_node", b"max_replicas_per_node", "placement_group_bundles", b"placement_group_bundles", "placement_group_strategy", b"placement_group_strategy", "ray_actor_options", b"ray_actor_options"]) -> None: ...

global___ReplicaConfig = ReplicaConfig

@typing_extensions.final
class DeploymentInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DEPLOYMENT_CONFIG_FIELD_NUMBER: builtins.int
    REPLICA_CONFIG_FIELD_NUMBER: builtins.int
    START_TIME_MS_FIELD_NUMBER: builtins.int
    ACTOR_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    END_TIME_MS_FIELD_NUMBER: builtins.int
    TARGET_CAPACITY_FIELD_NUMBER: builtins.int
    TARGET_CAPACITY_DIRECTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def deployment_config(self) -> global___DeploymentConfig: ...
    @property
    def replica_config(self) -> global___ReplicaConfig: ...
    start_time_ms: builtins.int
    actor_name: builtins.str
    version: builtins.str
    end_time_ms: builtins.int
    target_capacity: builtins.float
    target_capacity_direction: global___TargetCapacityDirection.ValueType
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        deployment_config: global___DeploymentConfig | None = ...,
        replica_config: global___ReplicaConfig | None = ...,
        start_time_ms: builtins.int = ...,
        actor_name: builtins.str = ...,
        version: builtins.str = ...,
        end_time_ms: builtins.int = ...,
        target_capacity: builtins.float = ...,
        target_capacity_direction: global___TargetCapacityDirection.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment_config", b"deployment_config", "replica_config", b"replica_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actor_name", b"actor_name", "deployment_config", b"deployment_config", "end_time_ms", b"end_time_ms", "name", b"name", "replica_config", b"replica_config", "start_time_ms", b"start_time_ms", "target_capacity", b"target_capacity", "target_capacity_direction", b"target_capacity_direction", "version", b"version"]) -> None: ...

global___DeploymentInfo = DeploymentInfo

@typing_extensions.final
class DeploymentRoute(google.protobuf.message.Message):
    """Wrap DeploymentInfo and route. The "" route value need to be convert to
    None/null.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_INFO_FIELD_NUMBER: builtins.int
    ROUTE_FIELD_NUMBER: builtins.int
    @property
    def deployment_info(self) -> global___DeploymentInfo: ...
    route: builtins.str
    def __init__(
        self,
        *,
        deployment_info: global___DeploymentInfo | None = ...,
        route: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment_info", b"deployment_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_info", b"deployment_info", "route", b"route"]) -> None: ...

global___DeploymentRoute = DeploymentRoute

@typing_extensions.final
class DeploymentRouteList(google.protobuf.message.Message):
    """Wrap a list for DeploymentRoute."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_ROUTES_FIELD_NUMBER: builtins.int
    @property
    def deployment_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentRoute]: ...
    def __init__(
        self,
        *,
        deployment_routes: collections.abc.Iterable[global___DeploymentRoute] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_routes", b"deployment_routes"]) -> None: ...

global___DeploymentRouteList = DeploymentRouteList

@typing_extensions.final
class DeploymentStatusInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    STATUS_TRIGGER_FIELD_NUMBER: builtins.int
    name: builtins.str
    status: global___DeploymentStatus.ValueType
    message: builtins.str
    status_trigger: global___DeploymentStatusTrigger.ValueType
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        status: global___DeploymentStatus.ValueType = ...,
        message: builtins.str = ...,
        status_trigger: global___DeploymentStatusTrigger.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "name", b"name", "status", b"status", "status_trigger", b"status_trigger"]) -> None: ...

global___DeploymentStatusInfo = DeploymentStatusInfo

@typing_extensions.final
class DeploymentStatusInfoList(google.protobuf.message.Message):
    """Wrap a list for DeploymentStatusInfo."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_STATUS_INFOS_FIELD_NUMBER: builtins.int
    @property
    def deployment_status_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentStatusInfo]: ...
    def __init__(
        self,
        *,
        deployment_status_infos: collections.abc.Iterable[global___DeploymentStatusInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_status_infos", b"deployment_status_infos"]) -> None: ...

global___DeploymentStatusInfoList = DeploymentStatusInfoList

@typing_extensions.final
class ApplicationStatusInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    DEPLOYMENT_TIMESTAMP_FIELD_NUMBER: builtins.int
    status: global___ApplicationStatus.ValueType
    message: builtins.str
    deployment_timestamp: builtins.float
    def __init__(
        self,
        *,
        status: global___ApplicationStatus.ValueType = ...,
        message: builtins.str = ...,
        deployment_timestamp: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_timestamp", b"deployment_timestamp", "message", b"message", "status", b"status"]) -> None: ...

global___ApplicationStatusInfo = ApplicationStatusInfo

@typing_extensions.final
class StatusOverview(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_STATUS_FIELD_NUMBER: builtins.int
    DEPLOYMENT_STATUSES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def app_status(self) -> global___ApplicationStatusInfo: ...
    @property
    def deployment_statuses(self) -> global___DeploymentStatusInfoList: ...
    name: builtins.str
    def __init__(
        self,
        *,
        app_status: global___ApplicationStatusInfo | None = ...,
        deployment_statuses: global___DeploymentStatusInfoList | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_status", b"app_status", "deployment_statuses", b"deployment_statuses"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_status", b"app_status", "deployment_statuses", b"deployment_statuses", "name", b"name"]) -> None: ...

global___StatusOverview = StatusOverview

@typing_extensions.final
class ListApplicationsRequest(google.protobuf.message.Message):
    """Used for gRPC proxy health check"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListApplicationsRequest = ListApplicationsRequest

@typing_extensions.final
class ListApplicationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_NAMES_FIELD_NUMBER: builtins.int
    @property
    def application_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        application_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_names", b"application_names"]) -> None: ...

global___ListApplicationsResponse = ListApplicationsResponse

@typing_extensions.final
class HealthzRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HealthzRequest = HealthzRequest

@typing_extensions.final
class HealthzResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___HealthzResponse = HealthzResponse

@typing_extensions.final
class UserDefinedMessage(google.protobuf.message.Message):
    """Used for gRPC related tests"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    FOO_FIELD_NUMBER: builtins.int
    NUM_FIELD_NUMBER: builtins.int
    name: builtins.str
    foo: builtins.str
    num: builtins.int
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        foo: builtins.str = ...,
        num: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["foo", b"foo", "name", b"name", "num", b"num"]) -> None: ...

global___UserDefinedMessage = UserDefinedMessage

@typing_extensions.final
class UserDefinedResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GREETING_FIELD_NUMBER: builtins.int
    NUM_X2_FIELD_NUMBER: builtins.int
    greeting: builtins.str
    num_x2: builtins.int
    def __init__(
        self,
        *,
        greeting: builtins.str = ...,
        num_x2: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["greeting", b"greeting", "num_x2", b"num_x2"]) -> None: ...

global___UserDefinedResponse = UserDefinedResponse

@typing_extensions.final
class UserDefinedMessage2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UserDefinedMessage2 = UserDefinedMessage2

@typing_extensions.final
class UserDefinedResponse2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GREETING_FIELD_NUMBER: builtins.int
    greeting: builtins.str
    def __init__(
        self,
        *,
        greeting: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["greeting", b"greeting"]) -> None: ...

global___UserDefinedResponse2 = UserDefinedResponse2

@typing_extensions.final
class FruitAmounts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORANGE_FIELD_NUMBER: builtins.int
    APPLE_FIELD_NUMBER: builtins.int
    BANANA_FIELD_NUMBER: builtins.int
    orange: builtins.int
    apple: builtins.int
    banana: builtins.int
    def __init__(
        self,
        *,
        orange: builtins.int = ...,
        apple: builtins.int = ...,
        banana: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["apple", b"apple", "banana", b"banana", "orange", b"orange"]) -> None: ...

global___FruitAmounts = FruitAmounts

@typing_extensions.final
class FruitCosts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COSTS_FIELD_NUMBER: builtins.int
    costs: builtins.float
    def __init__(
        self,
        *,
        costs: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["costs", b"costs"]) -> None: ...

global___FruitCosts = FruitCosts

@typing_extensions.final
class ArrayData(google.protobuf.message.Message):
    """Used for gRPC benchmark"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUMS_FIELD_NUMBER: builtins.int
    @property
    def nums(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        nums: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nums", b"nums"]) -> None: ...

global___ArrayData = ArrayData

@typing_extensions.final
class StringData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    data: builtins.str
    def __init__(
        self,
        *,
        data: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data"]) -> None: ...

global___StringData = StringData

@typing_extensions.final
class ModelOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_FIELD_NUMBER: builtins.int
    output: builtins.float
    def __init__(
        self,
        *,
        output: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["output", b"output"]) -> None: ...

global___ModelOutput = ModelOutput

@typing_extensions.final
class DeploymentArgs(google.protobuf.message.Message):
    """The required deployment parameters when deploying an application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_NAME_FIELD_NUMBER: builtins.int
    DEPLOYMENT_CONFIG_FIELD_NUMBER: builtins.int
    REPLICA_CONFIG_FIELD_NUMBER: builtins.int
    DEPLOYER_JOB_ID_FIELD_NUMBER: builtins.int
    ROUTE_PREFIX_FIELD_NUMBER: builtins.int
    INGRESS_FIELD_NUMBER: builtins.int
    DOCS_PATH_FIELD_NUMBER: builtins.int
    deployment_name: builtins.str
    deployment_config: builtins.bytes
    replica_config: builtins.bytes
    deployer_job_id: builtins.str
    route_prefix: builtins.str
    ingress: builtins.bool
    docs_path: builtins.str
    def __init__(
        self,
        *,
        deployment_name: builtins.str = ...,
        deployment_config: builtins.bytes = ...,
        replica_config: builtins.bytes = ...,
        deployer_job_id: builtins.str = ...,
        route_prefix: builtins.str | None = ...,
        ingress: builtins.bool = ...,
        docs_path: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_docs_path", b"_docs_path", "_route_prefix", b"_route_prefix", "docs_path", b"docs_path", "route_prefix", b"route_prefix"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_docs_path", b"_docs_path", "_route_prefix", b"_route_prefix", "deployer_job_id", b"deployer_job_id", "deployment_config", b"deployment_config", "deployment_name", b"deployment_name", "docs_path", b"docs_path", "ingress", b"ingress", "replica_config", b"replica_config", "route_prefix", b"route_prefix"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_docs_path", b"_docs_path"]) -> typing_extensions.Literal["docs_path"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_route_prefix", b"_route_prefix"]) -> typing_extensions.Literal["route_prefix"] | None: ...

global___DeploymentArgs = DeploymentArgs
